summaryrefslogtreecommitdiffstats
path: root/kommander/editor/actiondnd.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kommander/editor/actiondnd.cpp')
-rw-r--r--kommander/editor/actiondnd.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kommander/editor/actiondnd.cpp b/kommander/editor/actiondnd.cpp
index 3910b4cf..ae25449c 100644
--- a/kommander/editor/actiondnd.cpp
+++ b/kommander/editor/actiondnd.cpp
@@ -96,7 +96,7 @@ void QDesignerToolBarSeparator::styleChange( TQStyle& )
TQSize QDesignerToolBarSeparator::sizeHint() const
{
- int extent = tqstyle().pixelMetric( TQStyle::PM_DockWindowSeparatorExtent,
+ int extent = style().pixelMetric( TQStyle::PM_DockWindowSeparatorExtent,
this );
if ( orient ==Qt::Horizontal )
return TQSize( extent, 0 );
@@ -112,7 +112,7 @@ void QDesignerToolBarSeparator::paintEvent( TQPaintEvent * )
if ( orientation() ==Qt::Horizontal )
flags |= TQStyle::Style_Horizontal;
- tqstyle().tqdrawPrimitive( TQStyle::PE_DockWindowSeparator, &p, rect(),
+ style().tqdrawPrimitive( TQStyle::PE_DockWindowSeparator, &p, rect(),
colorGroup(), flags );
}
@@ -746,9 +746,9 @@ void QDesignerMenuBar::contextMenuEvent( TQContextMenuEvent *e )
idAt( itm ), itm, item->text() );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
- // #### need to do a proper invalidate and re-tqlayout
- parentWidget()->tqlayout()->invalidate();
- parentWidget()->tqlayout()->activate();
+ // #### need to do a proper invalidate and re-layout
+ parentWidget()->layout()->invalidate();
+ parentWidget()->layout()->activate();
} else if ( res == 2 ) {
bool ok;
TQString old = text( idAt( itm ) );